# Security Policy

## Introduction

I take the security of the EasyTL library very seriously. I appreciate your efforts to responsibly disclose your findings and will make every effort to acknowledge your contributions.

## Reporting a Vulnerability

Please report (suspected) security vulnerabilities to **[Bikatr7@proton.me](mailto:Bikatr7@proton.me)**. You should receive a response within 48 hours. If the issue is confirmed, I will release a patch as soon as possible depending on the complexity but typically within a few days.

### What to include in a security report

- The version of EasyTL you are using
- A description of the vulnerability
- The potential impact of the vulnerability
- Steps to reproduce or proof of concept

This information will help me to swiftly resolve potential vulnerabilities.

## Encrypted Communication

If you believe that your message needs to be encrypted, you can use this PGP Key so that only I can read it.
```plaintext
-----BEGIN PGP PUBLIC KEY BLOCK-----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=025c
-----END PGP PUBLIC KEY BLOCK-----
```

## Policy on Security Updates

I will keep you informed of the progress towards fixing the vulnerability and announce the patched version once it is available.

## Acknowledgements

Individuals who report security vulnerabilities responsibly will be acknowledged in the project documentation. If you would like to be acknowledged, please include a name or alias in your report.

Please note: Public disclosure of the vulnerability without prior agreement is not recommended, as it could put the wider user community at risk.